@@ -9,7 +9,7 @@ use CPAN::Packager::Config::Loader;
 use CPAN::Packager::Util;
 with 'CPAN::Packager::Role::Logger';
 
-our $VERSION = '0.071';
+our $VERSION = '0.072';
 
 BEGIN {
     if ( !defined &DEBUG ) {
@@ -171,6 +171,13 @@ CPAN::Packager - Create packages(rpm, deb) from perl modules
 =head1 SYNOPSIS
 
   use CPAN::Packager;
+  my $packager = CPAN::Packager->new(
+        builder      => 'RPM',
+        conf         => '/home/dann/config-rpm.yaml',
+        always_build => 1,
+        dry_run      => 0,
+  );
+  $packager->make('Mouse');
 
 =head1 DESCRIPTION
 
