@@ -4,13 +4,14 @@ use Carp;
 use IPC::System::Simple qw(system);
 use Path::Class;
 use List::MoreUtils qw(any);
+use CPAN::Packager::Home;
 with 'CPAN::Packager::Builder::Role';
 with 'CPAN::Packager::Role::Logger';
 
 has 'package_output_dir' => (
     +default => sub {
         my $self = shift;
-        dir( '/', 'tmp', 'cpanpackager', 'deb' );
+        dir( CPAN::Packager::Home->detect, 'deb' );
     },
 );
 
@@ -81,7 +82,8 @@ sub _build_dh_make_perl_command {
     my $depends = join ',', @depends;
     $self->log( debug => "depends: $depends" );
     my $dh_make_perl_cmd
-        = "dh-make-perl --build --depends '$depends' $module->{src} --package $package ";
+    # = "dh-make-perl --build --depends '$depends' $module->{src} --package $package "; # hmm. etch's dh-make-perl don't have --package option.
+        = "dh-make-perl --build --depends '$depends' $module->{src}";
     if ( $module->{skip_test} ) {
         $dh_make_perl_cmd .= " --notest";
     }
